# core-form.md
## affirm
correct
ye
uh yes
let's do it
yeah
uh yes
um yes
yes knocking
that's correct
yes yes
right
yea
yes
yes right
yes and i dont care
right on
i love that

## deny
no
no new selection
no thanks
no thank you
uh no
breath no
do you have something else
no this does not work for me

## thankyou
+ noworries "you are welcome :)"

um thank you good bye
okay cool uh good bye thank you
okay thank you good bye
you rock
and thats all thank you and good bye
thank you and good bye
sorry about my mistakes thank you good bye
noise thank you good bye
thank you goodbye noise
okay thank you goodbye
uh thank you good bye
thank you goodbye
thank you goodbye noise thank you goodbye
breath thank you goodbye
thank you
okay thank you
thanks goodbye
ah thank you goodbye
thank you noise
thank you good bye
breath thank you very much goodbye
thanks
noise thank you goodbye
unintelligible thank you goodbye
uh okay thank you good bye
thank you bye
um okay thank you good bye

## chitchat
+ chitchat "chitchat"

can you share your boss with me?
i want to get to know your owner
i want to know the company which designed you
i want to know the company which generated you
i want to know the company which invented you
i want to know who invented you
May I ask who invented you?
please tell me the company who created you
please tell me who created you
tell me more about your creators
tell me more about your founders
Ahoy matey how are you?
are you alright
are you having a good day
Are you ok?
are you okay
Do you feel good?
how are things going
how are things with you?
How are things?
how are you
how are you doing
how are you doing this morning
how are you feeling
how are you today
How are you?
How is the weather today?
What's the weather like?
How is the weather?
What is the weather at your place?
Do you have good weather?
Is it raining?
What's it like out there?
Is it hot or cold?
Beautiful day, isn't it?
What's the weather forecast?
Is it quite breezy outside?

## stop
+ ask continue "do you want to continue?"

ok then you cant help me
that was shit, you're not helping
you can't help me
you can't help me with what i need
i guess you can't help me then
ok i guess you can't help me
that's not what i want
ok, but that doesnt help me
this is leading to nothing
this conversation is not really helpful
you cannot help me with what I want
I think you cant help me
hm i don't think you can do what i want
stop
stop go back
do you get anything?
and you call yourself bot company? pff
and that's it?
nothing else?
